/*
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2023-03-20 10:41:16
 */
import request from '@/utils/request'
// 提货赠送活动-增删改
export function pickProductOnlinePetition(data) {
  return request({
    url: '/activity/manage/pick-product-config/online-petition',
    method: 'post',
    data
  })
}
// 会员消费赠送-增删改
export function consumeOnlinePetition(data) {
  return request({
    url: '/activity/manage/member-consume-rule/online-petition',
    method: 'post',
    data
  })
}
// 待办数据
export function waitApproval(params) {
  return request({
    url: '/system/manage/index/wait-approval',
    method: 'get',
    params
  })
}

// 待办数量
export function waitApprovalNum(params) {
  return request({
    url: '/system/manage/index/wait-approval-num',
    method: 'get',
    params
  })
}

// 签呈接收数量
export function receiveApprovalNum(params) {
  return request({
    url: '/system/manage/index/receive-approval-num',
    method: 'get',
    params
  })
}

// 已办数据
export function completeApproval(params) {
  return request({
    url: '/system/manage/index/complete-approval',
    method: 'get',
    params
  })
}

// 接收数据
export function receiveApprovalList(params) {
  return request({
    url: '/system/manage/index/receive-approval-list',
    method: 'get',
    params
  })
}

// 接收
export function receiveApproval(data) {
  return request({
    url: '/system/manage/index/receive-approval',
    method: 'PUT',
    data
  })
}

// 审批详情
export function approvalDetails(id) {
  return request({
    url: '/system/manage/approval-business/detail/' + id,
    method: 'get'
  })
}

// 审批下拉
export function approvalOperation(params) {
  return request({
    url: '/system/pub/enums/approval-operation',
    method: 'get',
    params
  })
}

// 审批状态
// export function approvalStatus(params) {
//   return request({
//     url: '/system/pub/enums/approval-status',
//     method: 'get',
//     params
//   })
// }
// 审批状态
export function approvalStatus(params) {
  return request({
    url: '/system/pub/enums/approval-status-submit',
    method: 'get',
    params
  })
}

// 来源下拉
export function signSource(params) {
  return request({
    url: '/system/pub/enums/sign-source',
    method: 'get',
    params
  })
}

// 来源下拉1
export function noticeWebsite(params) {
  return request({
    url: '/system/pub/enums/sign-source-first-two',
    method: 'get',
    params
  })
}
// 来源下拉
export function noticeWebsiteType(params) {
  return request({
    url: '/system/pub/enums/notice-website-type',
    method: 'get',
    params
  })
}
// 审批业务类型
export function approvalBusiness(params) {
  return request({
    url: '/system/pub/enums/approval-business',
    method: 'get',
    params
  })
}

// 签呈类型
export function signType(params) {
  return request({
    url: '/system/pub/enums/sign-type',
    method: 'get',
    params
  })
}

// 签呈审核
export function approvalTrue(data) {
  return request({
    url: '/system/manage/approval-business/approval',
    method: 'put',
    data
  })
}

// 签呈配置内容
export function signData(id) {
  return request({
    url: '/system/manage/approval/sign-data/' + id,
    method: 'get'
  })
}

// 可审批管理员
export function approvalUser(params) {
  return request({
    url: '/system/manage/user/approval-user',
    method: 'get',
    params
  })
}

// 日常申请审批管理员
export function usualApprovalUser(params) {
  return request({
    url: '/system/manage/user/usual-approval-user',
    method: 'get',
    params
  })
}

// 签呈提交
export function petitionConfirm(data) {
  return request({
    url: '/member/manage/handle-business/online-petition-confirm',
    method: 'post',
    data
  })
}

// 提货卡签呈提交
export function rechargeConfirm(data) {
  return request({
    url: '/activity/manage/pick/submit',
    method: 'post',
    data
  })
}

// 提货卡签呈提交删除
export function rechargeDel(data) {
  return request({
    url: '/activity/manage/pick/del-pick',
    method: 'post',
    data
  })
}

// 提现签呈提交
export function withdrawConfirm(data) {
  return request({
    url: '/member/manager/withdraw/confirm-withdraw-petition',
    method: 'post',
    data
  })
}

// 修改地址签呈提交
export function addressConfirm(data) {
  return request({
    url: '/sale/manage/order-business/address-confirm',
    method: 'post',
    data
  })
}

// 调换货物签呈提交
export function productConfirm(data) {
  return request({
    url: '/sale/manage/order-business/product-confirm',
    method: 'post',
    data
  })
}

// 退单签呈提交
export function returnConfirm(data) {
  return request({
    url: '/sale/manage/order-business/return-confirm',
    method: 'post',
    data
  })
}

// 合并退单签呈提交
export function returnConfirmMerge(data) {
  return request({
    url: '/sale/manage/order-business/return-batch-confirm',
    method: 'post',
    data
  })
}

// 撤销订单签呈提交
export function cancelOrderConfirm(data) {
  return request({
    url: '/sale/manage/order-business/cancel-order-confirm',
    method: 'post',
    data
  })
}

// 上传图片
export function upload(data) {
  return request({
    url: '/system/upload',
    method: 'post',
    data
  })
}

// 修改直推
export function updateParent(data) {
  return request({
    url: '/member/manage/update-parent/petition',
    method: 'post',
    data
  })
}

// 修改安置
export function updatReplaceParent(data) {
  return request({
    url: 'member/manage/update-place-parent/petition',
    method: 'post',
    data
  })
}

// 修改编号
export function updatePetition(data) {
  return request({
    url: '/member/manager/updatecode/petition',
    method: 'post',
    data
  })
}

// 修改结算国签呈
export function countryPetition(data) {
  return request({
    url: '/member/manage/update-settle-country/petition',
    method: 'post',
    data
  })
}

// 京东代付新增提现签呈
export function jdSave(data) {
  return request({
    url: '/pay/manage/jd-agent/save',
    method: 'post',
    data
  })
}

// 发布公告（前台）签呈
export function noticeSave(data) {
  return request({
    url: '/system/manage/notice/save',
    method: 'post',
    data
  })
}

// 发布公告（后台）签呈
export function noticeAdminSave(data) {
  return request({
    url: '/system/manage/notice/admin-save',
    method: 'post',
    data
  })
}

// 站内信签呈
export function messageSave(data) {
  return request({
    url: '/system/manage/platform/message/save',
    method: 'post',
    data
  })
}

// 真实奖衔新增
export function awardsControlSave(data) {
  return request({
    url: '/member/manage/awards-control/save-petition',
    method: 'post',
    data
  })
}

// 真实奖衔修改
export function awardsControlUp(data) {
  return request({
    url: '/member/manage/awards-control/up-petition',
    method: 'post',
    data
  })
}

// 真实奖衔删除
export function awardsControlDel(data) {
  return request({
    url: '/member/manage/awards-control/del-petition',
    method: 'post',
    data
  })
}

// 注水签呈
export function waterPetition(data) {
  return request({
    url: '/member/manager/member-achieve-log/petition',
    method: 'post',
    data
  })
}

// 空单注册
export function emptyOrderPetition(data) {
  return request({
    url: '/sale/manage/order/register-empty-order',
    method: 'post',
    data
  })
}

// 自提签呈
export function selfDeliver(data) {
  return request({
    url: '/sale/manage/deliver-unhandled/self-deliver',
    method: 'post',
    data
  })
}

// 户籍变更发起签呈
export function domicileChangeAgree(data) {
  return request({
    url: '/member/manage/change-domicile/domicile-change-agree',
    method: 'post',
    data
  })
}

// 修改政策币发起签呈
export function updatePolicy(data) {
  return request({
    url: '/member/manage/update-policy-currency/petition',
    method: 'post',
    data
  })
}

// 全部管理员
export function userAll(params) {
  return request({
    url: '/system/manage/user/all',
    method: 'get',
    params
  })
}

// 自定义签呈列表
export function customList(params) {
  return request({
    url: '/system/manage/approval-business/custom-list',
    method: 'get',
    params
  })
}

// 直推活动在线签呈
export function recommendPetition(data) {
  return request({
    url: '/activity/manage/recommend/online-petition',
    method: 'post',
    data
  })
}

// 权益赠送新增
export function benefitsAdd(data) {
  return request({
    url: '/activity/manage/gift-benefits/save-petition',
    method: 'post',
    data
  })
}

// 权益赠送修改
export function benefitsUp(data) {
  return request({
    url: '/activity/manage/gift-benefits/up-petition',
    method: 'post',
    data
  })
}

// 权益赠送删除
export function benefitsDel(data) {
  return request({
    url: '/activity/manage/gift-benefits/del-petition',
    method: 'post',
    data
  })
}

// 升级权益赠送新增
export function upgradeGiveAdd(data) {
  return request({
    url: '/activity/manage/upgrade-give/save-petition',
    method: 'post',
    data
  })
}

// 升级权益赠送修改
export function upgradeGiveUp(data) {
  return request({
    url: '/activity/manage/upgrade-give/up-petition',
    method: 'post',
    data
  })
}

// 升级权益赠送删除
export function upgradeGiveDel(data) {
  return request({
    url: '/activity/manage/upgrade-give/del-petition',
    method: 'post',
    data
  })
}

// 二次发货在线签呈
export function deliverSecond(data) {
  return request({
    url: '/sale/manage/deliver-second/submit',
    method: 'post',
    data
  })
}

// 地区转换
export function areaChange(params) {
  return request({
    url: '/system/manage/area/query-name',
    method: 'get',
    params
  })
}

// 账户转换
export function accountChange(params) {
  return request({
    url: '/system/manage/account/query-name',
    method: 'get',
    params
  })
}

// 已读状态
export function readState(params) {
  return request({
    url: '/system/pub/enums/read-state',
    method: 'get',
    params
  })
}

// 提货卡列表
export function getPickList(params) {
  return request({
    url: '/activity/manage/pick/list',
    method: 'get',
    params
  })
}

// 提货卡详情
export function pickDetail(params) {
  return request({
    url: '/activity/manage/pick/detail',
    method: 'get',
    params
  })
}

// 公告弹框
export function noticeShow(params) {
  return request({
    url: '/system/manage/notice/show-admin',
    method: 'get',
    params
  })
}

// 通过修改地址
export function passAddress(data) {
  return request({
    url: '/member/manage/self-modify-address/pass',
    method: 'post',
    data
  })
}

// 删除公共
export function deleteNotice(data) {
  return request({
    url: '/system/manage/notice/delete-notice-petition',
    method: 'post',
    data
  })
}

// 空单提交
export function emptySubmit(data) {
  return request({
    url: '/member/manage/member-empty/submit',
    method: 'post',
    data
  })
}

// 营业执照审核
export function licenseAgree(data) {
  return request({
    url: '/member/manager/business/license/agree',
    method: 'post',
    data
  })
}

// 营业执照重置
export function licenseReset(data) {
  return request({
    url: '/member/manager/business/license/resetting',
    method: 'post',
    data
  })
}

// 0元撤单发起签呈
export function zeroRevokeConfirm(data) {
  return request({
    url: '/member/manager/zeroRevoke/petition',
    method: 'post',
    data
  })
}

// 采购订单发起签呈
export function submitPoList(data) {
  return request({
    url: '/scm/manage/po/submit',
    method: 'post',
    data
  })
}

// 采购入库单发起前程
export function submitPurchase(data) {
  return request({
    url: '/scm/manage/purchase/submit',
    method: 'post',
    data
  })
}

// 调拨订单发起前程
export function submitTrans(data) {
  return request({
    url: '/scm/manage/trans-order/submit',
    method: 'post',
    data
  })
}

// 调拨出库单发起前程
export function transOutTrans(data) {
  return request({
    url: '/scm/manage/trans-out/submit',
    method: 'post',
    data
  })
}

// 调拨入库单发起前程
export function transInTrans(data) {
  return request({
    url: '/scm/manage/trans-in/submit',
    method: 'post',
    data
  })
}

// 日常申请发起签呈
export function submitCustom(data) {
  return request({
    url: '/system/manage/approval-business/submit-custom',
    method: 'post',
    data
  })
}

// 日常申请发起签呈暂存
export function stagingCustom(data) {
  return request({
    url: '/system/manage/approval-business/staging-custom',
    method: 'post',
    data
  })
}

// 日常申请撤回签呈
export function revokeCustom(data) {
  return request({
    url: '/system/manage/approval-business/revoke-custom',
    method: 'post',
    data
  })
}

// 日常申请作废签呈
export function cancelCustom(data) {
  return request({
    url: '/system/manage/approval-business/cancel-custom',
    method: 'post',
    data
  })
}

// 直推数据发起签呈
export function directPetition(data) {
  return request({
    url: '/report/manager/member-awards/petition',
    method: 'post',
    data
  })
}

// 其他入库发起前程
export function submitGeneralin(data) {
  return request({
    url: '/scm/manage/general-in/submit',
    method: 'post',
    data
  })
}

// 其他出库发起前程
export function submitGeneralout(data) {
  return request({
    url: '/scm/manage/general-out/submit',
    method: 'post',
    data
  })
}

// 库存盘点发起前程
export function inventorySub(data) {
  return request({
    url: '/scm/manage/inventory/submit',
    method: 'post',
    data
  })
}

// 销售退货发起前程
export function generalSubmit(data) {
  return request({
    url: '/scm/manage/sale-out/submit',
    method: 'post',
    data
  })
}

// 采购入库单发起前程
export function purchaseSubmit(data) {
  return request({
    url: '/scm/manage/purchase/out-submit',
    method: 'post',
    data
  })
}

// 旅游活动签呈
export function tourismOnline(data) {
  return request({
    url: '/activity/manage/tourism/online-petition',
    method: 'post',
    data
  })
}

// 商品赠送
export function waresOnline(data) {
  return request({
    url: 'activity/manage/wares-rule-config/online-petition',
    method: 'post',
    data
  })
}

// 消费赠送
export function consumeOnline(data) {
  return request({
    url: 'activity/manage/consume-rule-config/online-petition',
    method: 'post',
    data
  })
}

// 种植
export function treeOnline(data) {
  return request({
    url: 'activity/manage/tree-rule-pick/online-petition',
    method: 'post',
    data
  })
}

// 供应商商品签呈审批
export function thProductOnline(data) {
  return request({
    url: 'scm/manage/th-product/online-petition',
    method: 'post',
    data
  })
}

// 业务领用发起签呈
export function submitIoList(data) {
  return request({
    url: '/scm/manage/io/submit',
    method: 'post',
    data
  })
}

// 订单抵扣发起签呈
export function submitDeduction(data) {
  return request({
    url: '/sale/manage/deliver-unhandled/deduction-submit',
    method: 'post',
    data
  })
}

// 会员续约发起签呈
export function submitMemberRenewal(data) {
  return request({
    url: '/member/manager/updateExpireStop/upExpireStop',
    method: 'post',
    data
  })
}

// 免密登录
export function freeLogin(data) {
  return request({
    url: '/system/manage/user/free-login',
    method: 'post',
    data
  })
}
